@@ -52,6 +52,7 @@ class Lister(RESTInterface):
         cancelled: Optional[bool] = None,
         errored: Optional[bool] = None,
         archived: Optional[bool] = None,
+        completed: Optional[bool] = None,
         name: Optional[str] = None,
         name_like: Optional[str] = None,
         format: Optional[LogFormat] = None,
@@ -66,6 +67,7 @@ class Lister(RESTInterface):
         progress_lte: Optional[float] = None,
         error_like: Optional[str] = None,
         note_like: Optional[str] = None,
+        context_filter: Optional[dict] = None,
         created_by: Optional[UUID] = None,
         updated_by: Optional[UUID] = None,
         deleted_by: Optional[UUID] = None,
@@ -196,6 +198,7 @@ class Lister(RESTInterface):
         cancelled: Optional[bool] = None,
         errored: Optional[bool] = None,
         archived: Optional[bool] = None,
+        completed: Optional[bool] = None,
         format: Optional[LogFormat] = None,
         name: Optional[str] = None,
         name_like: Optional[str] = None,
@@ -211,6 +214,7 @@ class Lister(RESTInterface):
         meta_like: Optional[str] = None,
         error_like: Optional[str] = None,
         note_like: Optional[str] = None,
+        context_filter: Optional[dict] = None,
         start_offset_null: Optional[bool] = None,
         start_offset_gte: Optional[int] = None,
         start_offset_lte: Optional[int] = None,
@@ -244,6 +248,7 @@ class Lister(RESTInterface):
         order: Optional[str] = "created_at",
         sort: Optional[str] = "ASC",
         group_id: Optional[UUID] = None,
+        locked: Optional[bool] = None,
         start_time_null: Optional[bool] = None,
         start_time_gte: Optional[float] = None,
         start_time_lte: Optional[float] = None,
@@ -253,6 +258,7 @@ class Lister(RESTInterface):
         name: Optional[str] = None,
         name_like: Optional[str] = None,
         note_like: Optional[str] = None,
+        context_filter: Optional[dict] = None,
         created_by: Optional[UUID] = None,
         updated_by: Optional[UUID] = None,
         deleted_by: Optional[UUID] = None,
@@ -285,6 +291,7 @@ class Lister(RESTInterface):
         md5: Optional[str] = None,
         definition_like: Optional[str] = None,
         note_like: Optional[str] = None,
+        context_filter: Optional[dict] = None,
         created_by: Optional[UUID] = None,
         updated_by: Optional[UUID] = None,
         deleted_by: Optional[UUID] = None,
@@ -314,7 +321,8 @@ class Lister(RESTInterface):
         sort: Optional[str] = "ASC",
         log_id: Optional[UUID] = None,
         ingestion_id: Optional[UUID] = None,
-        data_filter: Optional[object] = None,
+        data_filter: Optional[dict] = None,
+        context_filter: Optional[dict] = None,
         frequency: Optional[float] = None,
         timestamp_gt: Optional[float] = None,
         timestamp_lt: Optional[float] = None,
@@ -328,6 +336,8 @@ class Lister(RESTInterface):
         offset_lte: Optional[int] = None,
         data_offset_gte: Optional[int] = None,
         data_offset_lte: Optional[int] = None,
+        nanosecond_gte: Optional[int] = None,
+        nanosecond_lte: Optional[int] = None,
         error_like: Optional[str] = None,
         note_like: Optional[str] = None,
         include_image: Optional[bool] = False,
@@ -363,9 +373,12 @@ class Lister(RESTInterface):
         log_id: Optional[UUID] = None,
         group_id: Optional[UUID] = None,
         message_type_id: Optional[UUID] = None,
+        associated_topic_id: Optional[UUID] = None,
         ingestion_id: Optional[UUID] = None,
+        locked: Optional[bool] = None,
         name: Optional[str] = None,
         name_like: Optional[str] = None,
+        context_filter: Optional[dict] = None,
         created_by: Optional[UUID] = None,
         updated_by: Optional[UUID] = None,
         deleted_by: Optional[UUID] = None,
